// Copyright (C) 2022 WYATT GROUP
// Please see the AUTHORS file for details.
//
// This program is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program. If not, see <https://www.gnu.org/licenses/>.

import 'dart:io';

import 'package:wyatt_cli_toolbox/src/sequences/sequences.dart';
import 'package:wyatt_cli_toolbox/src/stylish/stylish.dart';

/// Abstract class providing XTerm escape sequences
abstract class Control {
  /// Use Squences.escMoveUp, concatenate your string ([str])
  /// and then blank the remaining line.
  static String replacePreviousLine(String str) =>
      Sequences.escMoveUp(1) + str + Sequences.escClearLineFromCursorToEnd();

  /// Reset XTerm sequence.
  /// This is always applied after using some other sequence.
  static String reset = ''.reset();

  /// See: https://codepoints.net/dingbats
  static String questionIndicator() => '?'.green();

  static String exclamationIndicator() => '!'.yellow();

  static String infoIndicator() =>
      Platform.isWindows ? 'i'.cyan() : '\u2139'.cyan();

  static String rightIndicator() =>
      Platform.isWindows ? '>'.blue() : '\u276F'.blue();

  static String validIndicator() =>
      Platform.isWindows ? 'v'.green() : '\u2714'.green();

  static String wrongIndicator() =>
      Platform.isWindows ? 'x'.red() : '\u2718'.red();
}
