// Copyright (C) 2022 WYATT GROUP
// Please see the AUTHORS file for details.
//
// This program is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program. If not, see <https://www.gnu.org/licenses/>.

import 'dart:convert';
import 'dart:io';

import 'package:wyatt_cli_toolbox/src/prompt/question.dart';
import 'package:wyatt_cli_toolbox/src/sequences/sequences.dart';
import 'package:wyatt_cli_toolbox/src/stylish/stylish.dart';

class NumberQuestion extends Question<num> {
  NumberQuestion(String question, {String? comment, required String identifier})
      : super(QuestionType.stringQuestion, identifier, question, comment);

  num? answer;

  @override
  String formatComment() => (super.formatComment().trim().isEmpty)
      ? ' Mandatory! '.dim()
      : super.formatComment();

  @override
  num ask() {
    stdout.write(formatQuestion());
    String input = '';
    bool valid = false;
    num answer = 0;
    while (!valid) {
      input = stdin.readLineSync(encoding: utf8)!.trim();
      try {
        valid = input.isNotEmpty;
        answer = num.parse(input);
      } catch (e) {
        valid = false;
      }
      stdout.write(Sequences.escMoveUp(1) + formatQuestion());
    }
    stdout.writeln(
      // ignore: lines_longer_than_80_chars
      '\r${formatQuestion()}${answer.toString().blue()}${Sequences.escClearLineFromCursorToEnd()}',
    );
    return answer;
  }
}
